# Macrocosmos Protobufs
Protobufs used by Macrocosmos products

# Usage
Here is an example of how to add the Macrocosmos protobufs to a project:

```bash
git subtree add --prefix=protos git@github.com:macrocosm-os/macrocosmos-protos.git main --squash
```

They can subsequently be updated with:

```bash
git subtree pull --prefix=protos git@github.com:macrocosm-os/macrocosmos-protos.git main --squash
```
